=======
Credits
=======

Development Lead
----------------

* SekouD <sekoud.python@gmail.com>
* GPG key ID: B51D1046EF63C50B

https://github.com/SekouD/

Contributors
------------

None yet. Why not be the first?
